@@ -17,6 +17,8 @@ from wand.image import Image
 import pcbnew
 from lxml import etree
 
+PKG_BASE = os.path.dirname(__file__)
+
 default_style = {
     "copper": "#417e5a",
     "board": "#4ca06c",
@@ -584,17 +586,28 @@ def build_highlight(preset, width, height, pos, origin, ref):
         -math.degrees(pos[2]), -origin[0], -origin[1])
     h.attrib["id"] = "h_" + ref
 
-def svg_to_png(infile, outfile, dpi=300):
-    with Image(resolution=300) as image:
+def svg_to_bitmap(infile, outfile, dpi=300):
+    with Image(resolution=dpi) as image:
         with Color('transparent') as background_color:
             library.MagickSetBackgroundColor(image.wand,
                                             background_color.resource)
-        image.read(filename=infile, resolution=300)
-        png_image = image.make_blob("png32")
+        image.read(filename=infile, resolution=dpi)
+        _, ext = os.path.splitext(outfile)
+        print(ext)
+        if ext.lower() == ".png":
+            type = "png32"
+        elif ext.lower() in [".jpg", ".jpeg"]:
+            type = "jpeg"
+        else:
+            raise RuntimeError(f"Unsupported output image type {ext}")
+        bin_blob = image.make_blob(type)
         with open(outfile, "wb") as out:
-            out.write(png_image)
+            out.write(bin_blob)
 
 def load_style(style_file):
+    STYLES = os.path.join(PKG_BASE, "styles")
+    if style_file.startswith("builtin:"):
+        style_file = os.path.join(STYLES, style_file[len("builtin:"):])
     try:
         with open(style_file, "r") as f:
             style = json.load(f)
@@ -622,11 +635,10 @@ def load_remapping(remap_file):
         raise RuntimeError("Cannot open remapping file " + remap_file)
 
 def adjust_lib_path(path):
-    base = os.path.dirname(__file__)
     if path == "default" or path == "kicad-default":
-        return os.path.join(base, "footprints", "KiCAD-base")
+        return os.path.join(PKG_BASE, "footprints", "KiCAD-base")
     if path == "eagle-default":
-        return os.path.join(base, "footprints", "Eagle-export")
+        return os.path.join(PKG_BASE, "footprints", "Eagle-export")
     return path
 
 def main():
@@ -648,6 +660,7 @@ def main():
     parser.add_argument("-f", "--filter", help="comma separated list of components to show")
     parser.add_argument("-v", "--vcuts", action="store_true", help="Render V-CUTS on the Cmts.User layer")
     parser.add_argument("--silent", action="store_true", help="Silent warning messages about missing footprints")
+    parser.add_argument("--dpi", help="DPI for bitmap output", type=int, default=300)
 
     args = parser.parse_args()
     args.libs = [adjust_lib_path(path) for path in args.libs.split(',')]
@@ -664,8 +677,8 @@ def main():
         print(e)
         sys.exit(1)
 
-    if os.path.splitext(args.output)[-1].lower() not in [".svg", ".png"]:
-        print("Output can be either an SVG or PNG file")
+    if os.path.splitext(args.output)[-1].lower() not in [".svg", ".png", ".jpg", ".jpeg"]:
+        print("Output can be either an SVG, PNG or JPG file")
         sys.exit(1)
 
     try:
@@ -736,7 +749,7 @@ def main():
         with tempfile.NamedTemporaryFile(suffix=".svg") as tmp_f:
             document.write(tmp_f)
             tmp_f.flush()
-            svg_to_png(tmp_f.name, args.output)
+            svg_to_bitmap(tmp_f.name, args.output, dpi=args.dpi)
 
 if __name__ == '__main__':
     main()
\ No newline at end of file
